Call

Struct Call 

pub struct Call<M, R>
where M: Message, R: Message,
{ /* private fields */ }
Available on crate feature actor only.
A request together with the channel used to answer it.

Implementations

Source

impl<M, R> Call<M, R>
where M: Message, R: Message,

pub fn message(&self) -> &M

Get the request message.

pub fn reply(self, response: R) -> Result<(), R>

Answers the call, returning the response if the caller stopped waiting.

pub fn into_parts(self) -> (M, Reply<R>)

Splits the owned request from its reply capability.